@@ -373,7 +373,9 @@ static int queryjobs_cb(edg_wll_Context ctx, glite_jobid_t jobid, edg_wll_JobSta
 	store->jobs[n] = jobid;
 	store->jobs[n + 1] = NULL;
 
-	if (!(store->flags & EDG_WLL_STAT_NO_STATES)) {
+	if ((store->flags & EDG_WLL_STAT_NO_STATES)) {
+		edg_wll_FreeStatus(status);
+	} else {
 		if (status) store->states[n] = *status;
 		else memset(&store->states[n], 0, sizeof(*store->states));
 		memset(&store->states[n + 1], 0, sizeof(*store->states));
@@ -452,8 +454,7 @@ int edg_wll_QueryJobsServerStream(
 						eidrm = 0,
 						limit = 0, offset = 0,
 						limit_loop = 1,
-						where_flags = 0,
-						first_or;
+						where_flags = 0;
 	size_t				n = 0;
 
 
@@ -1944,8 +1945,9 @@ static int cmp_string(const char *s1,edg_wll_QueryOp op,const char *s2,const cha
 		case EDG_WLL_QUERY_OP_GREATER:	return strcmp(s1,s2)>0;
 		case EDG_WLL_QUERY_OP_WITHIN:
 			if (strcmp(s1, s2) >= 0 && strcmp(s1, s2b) <= 0) return 0;
+		default:
+			return 0;
 	}
-	return 0;
 }
 
 
