@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.server/src/stats.c,v 1.19 2012/06/08 09:29:44 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -83,9 +83,11 @@ int edg_wll_InitStatistics(edg_wll_Context ctx)
 {
 	edg_wll_Stats *stats = default_stats; 	/* XXX: hardcoded */
 	int	i,j;
+	char *zero = NULL;
+	size_t zero_size = 0;
 
 	for (i=0; stats[i].type; i++) {
-		char	fname[50],*zero;
+		char	fname[50];
 
 		strcpy(fname,"/tmp/lb_stats.XXXXXX");
 		stats[i].fd = mkstemp(fname);
@@ -99,7 +101,11 @@ int edg_wll_InitStatistics(edg_wll_Context ctx)
 			stats[i].grpsize += sizeof(struct edg_wll_stats_archive)-sizeof(struct edg_wll_stats_cell);
 			stats[i].grpsize += stats[i].archives[j].length * sizeof(struct edg_wll_stats_cell);
 		}
-		zero = calloc(1,stats[i].grpsize);
+		if (stats[i].grpsize > zero_size) {
+			free(zero);
+			zero = calloc(1, stats[i].grpsize);
+			zero_size = stats[i].grpsize;
+		}
 		write(stats[i].fd,zero,stats[i].grpsize);
 		stats[i].map = mmap(NULL,stats[i].grpsize,PROT_READ|PROT_WRITE,MAP_SHARED,stats[i].fd,0);
 		if (stats[i].map == MAP_FAILED) return edg_wll_SetError(ctx,errno,"mmap()");
@@ -119,6 +125,7 @@ int edg_wll_InitStatistics(edg_wll_Context ctx)
 			stats[i].htab = NULL;
 		}
 	}
+	free(zero);
 	return 0;
 }
 
